@@ -21,13 +21,18 @@ class Riak(BaseConnection):
     retryable_exceptions = frozenset([socket.error, httplib.HTTPException, RiakError])
     supports_pipelines = False
 
-    def __init__(self, host='127.0.0.1', port=8098, prefix='riak', mapred_prefix='mapred', client_id=None, **options):
+    def __init__(self, num, host='127.0.0.1', port=8098, prefix='riak', mapred_prefix='mapred', client_id=None,
+        transport_class=None, solr_transport_class=None, transport_options=None, **options):
+
         self.host = host
         self.port = port
         self.prefix = prefix
         self.mapred_prefix = mapred_prefix
         self.client_id = client_id
-        super(Riak, self).__init__(**options)
+        self.transport_class = transport_class
+        self.solr_transport_class = solr_transport_class
+        self.transport_options = transport_options
+        super(Riak, self).__init__(num)
 
     @property
     def identifier(self):
@@ -37,7 +42,9 @@ class Riak(BaseConnection):
     def connect(self):
         return RiakClient(
             host=self.host, port=self.port, prefix=self.prefix,
-            mapred_prefix=self.mapred_prefix, client_id=self.client_id)
+            mapred_prefix=self.mapred_prefix, client_id=self.client_id,
+            transport_class=self.transport_class, solr_transport_class=self.solr_transport_class,
+            transport_options=self.transport_options)
 
     def disconnect(self):
         pass
