@@ -1,8 +1,8 @@
 """
 nydus.db.routers.keyvalue
-~~~~~~~~~~~~~~~~~~~~~~
+~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2011 DISQUS.
+:copyright: (c) 2011-2012 DISQUS.
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
@@ -37,21 +37,17 @@ class ConsistentHashingRouter(RoundRobinRouter):
         self._db_num_id_map = {}
         super(ConsistentHashingRouter, self).__init__(*args, **kwargs)
 
-    def flush_down_connections(self):
-        for db_num in self._down_connections:
-            self._hash.add_node(self._db_num_id_map[db_num])
-
-        super(ConsistentHashingRouter, self).flush_down_connections()
-
     def mark_connection_down(self, db_num):
         db_num = self.ensure_db_num(db_num)
         self._hash.remove_node(self._db_num_id_map[db_num])
 
         super(ConsistentHashingRouter, self).mark_connection_down(db_num)
 
-    def mark_conenction_up(self, db_num):
+    def mark_connection_up(self, db_num):
         db_num = self.ensure_db_num(db_num)
-        self._hash.add_node(self._db_num_id_map[db_num])
+        node_key = self._db_num_id_map[db_num]
+        if self._hash.get_node(node_key) is None:
+            self._hash.add_node(node_key)
 
         super(ConsistentHashingRouter, self).mark_connection_up(db_num)
 
@@ -62,11 +58,18 @@ class ConsistentHashingRouter(RoundRobinRouter):
 
         return True
 
+    @routing_params
+    def _pre_routing(self, *args, **kwargs):
+        self.check_down_connections()
+
+        return super(ConsistentHashingRouter, self)._pre_routing(*args, **kwargs)
+
     @routing_params
     def _route(self, attr, args, kwargs, **fkwargs):
         """
         The first argument is assumed to be the ``key`` for routing.
         """
+
         key = get_key(args, kwargs)
 
         found = self._hash.get_node(key)
